@@ -1,4 +1,4 @@
-## Copyright (C) 2007-2015 Jordi Gutiérrez Hermoso
+## Copyright (C) 2007-2017 Jordi Gutiérrez Hermoso
 ## Copyright (C) 2007 Stallmanfacts.com
 ##
 ## This file is part of Octave.
@@ -18,8 +18,8 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn  {Command} {} fact
-## @deftypefnx {Function File} {@var{truth} =} fact ()
+## @deftypefn  {} {} fact
+## @deftypefnx {} {@var{truth} =} fact ()
 ## Display an amazing and random fact about the world's greatest hacker.
 ## @end deftypefn
 
@@ -46,7 +46,7 @@ function truth = fact ()
       "Richard Stallman's DNA is in binary.";
       "Richard Stallman's nervous system is completely wireless.";
       "Richard Stallman's brain accepts UNIX commands.";
-      "If Richard Stallman has 1GB of RAM, and if you have 1GB of RAM, Richard Stallman has more RAM than you.";
+      "If Richard Stallman has 1 GB of RAM, and if you have 1 GB of RAM, Richard Stallman has more RAM than you.";
       "Richard Stallman eats ethernet cables. That's why they invented wireless.";
       "Richard Stallman has a katana. 'Nuff said.";
       "Richard Stallman wrote a program that divides by zero.";
@@ -268,6 +268,7 @@ function truth = fact ()
 endfunction
 
 function out = wordwrap (w)
+
   ncol = terminal_size ()(2);
   wc = ostrsplit (w, " ");
   out = "\n";
@@ -278,15 +279,15 @@ function out = wordwrap (w)
     while (i < numwords
            && length (newline = [line " " wc{i+1}]) < ncol)
       line = newline;
-      i++;
+      i += 1;
     endwhile
     out = [out, line, "\n"];
-    i++;
+    i += 1;
   endwhile
   out = [out, "\n"];
+
 endfunction
 
 
 ## Mark file as being tested.  No real test needed for a documentation .m file
 %!assert (1)
-
